#
# spec file for package python-daiquiri
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-daiquiri
Version:        3.2.5.1
Release:        1.5
Summary:        Library to configure Python logging
License:        Apache-2.0
URL:            https://github.com/Mergifyio/daiquiri
Source:         https://files.pythonhosted.org/packages/source/d/daiquiri/daiquiri-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-json-logger}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-json-logger
BuildArch:      noarch
%python_subpackages

%description
The daiquiri library provides a way to configure logging. It also
provides some custom formatters and handlers.

%prep
%setup -q -n daiquiri-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Skip broken tests with python3.12 and not virtualenv,
# looks like the "taskName" field is not present in the output for
# some reason. Related to gh#Mergifyio/daiquiri#74
donttest="test_setup_json_formatter or test_output"
%pytest -k "not ($donttest)" daiquiri/tests

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/daiquiri
%{python_sitelib}/daiquiri-%{version}.dist-info

%changelog
* Mon Feb  5 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 3.2.5.1:
  * Only CI changes.
- Skip some tests that are failing with python 3.12 because of some
  issue in the way tests are running
  gh#Mergifyio/daiquiri#74
* Sat Dec  2 2023 Dirk Müller <dmueller@suse.com>
- update to 3.2.4:
  * Add support up to Python 3.12
  * Use sphinx-build command to generate doc
  * build system and CI improvements
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.2.1
  * chore: add custom LogRecord classes to avoid ignore
  * fix(output): correct Datadog handler class
  * fix: use _ version
- Update to 3.2.0
  * chore: type everything
  * refactor: remove Python 2 support leftover
  * chore: configure black
- Update to 3.1.1
  * fix: add missing py.typed
- Update to 3.1.0
  * fix: update setup.cfg
* Wed Nov 16 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed python-six dep
- Remove python_module macro definition
- More specific python_sitelib in %%files
* Thu Mar 10 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove BuildRequires on mock, it has not been required since 3.0.0.
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 3.0.1:
  * handle "stack_info" argument correctly
* Tue Nov 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.0.0:
  * Remove python 2 support
  * Add python 3.9 support
* Thu Apr  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.1.1
  * Add missing Python 3.8 to setup, tox and Mergify
  * build(setup): replace pbr by setuptools_scm
  * Parameterizes overwriting `sys.excepthook` to allow it to be turned
    off in environments where a different excepthook is needed.
  * fix(journal): handle extra keys correctly
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.6.0:
  * Fix getLogger when called twice and passing different extras
* Mon Apr  8 2019 Thomas Bechtold <tbechtold@suse.com>
- Do not use %%pytest to fix build with SLE12_SP4
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.0:
  * Support for python 3.7
  * Many Mergify fixes
  * Use pytests for testing
  * formatter: enable extra keywords by default
  * Fix JSON encoding with extra keys
  * Add tests for color and extras formatters
  * Add formatter.ExtrasFormatter and formatter.ColorExtrasFormatter
  * Add KeywordArgumentAdapter.setLevel method for Python 2
  * Many flake8 fixes
- Make sure tests are executed
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Aug  8 2017 jengelh@inai.de
- Use slightly longer description from README.rst.
  Drop subjective wording.
* Tue Aug  8 2017 tbechtold@suse.com
- fix Requires
* Fri Jul 28 2017 tbechtold@suse.com
- Initial packaging (version 1.2.1)
